@@ -147,7 +147,7 @@ class Request:
         headers = self.__generate_headers(
             default_headers=self.default_headers,
             extra_headers=extra_headers,
-            cookies=self.cookies,
+            all_cookies=self.cookies,
             use_cookies=use_cookies
         )
 
@@ -177,7 +177,7 @@ class Request:
             url=url,
             default_headers=self.default_headers,
             extra_headers=extra_headers,
-            cookies=self.cookies,
+            all_cookies=self.cookies,
             use_cookies=use_cookies
         )
 
@@ -196,7 +196,7 @@ class Request:
     # ------------------------------------------------------- Private methods -------------------------------------------------------- #
 
     def _clean_url(self, url: str) -> str:
-        url_comps = tldextract.extract(self.driver.current_url)
+        url_comps = tldextract.extract(url)
 
         return url_comps.domain + '.' + url_comps.suffix
 
@@ -216,10 +216,11 @@ class Request:
             self.__save_cookies()
 
     def __save_cookies(self):
-        cookies_path = self.__cookies_path()
+        if not self._cookies_path:
+            return
 
         try:
-            os.remove(cookies_path)
+            os.remove(self._cookies_path)
         except:
             pass
 
@@ -228,7 +229,7 @@ class Request:
 
         pickle.dump(
             self.cookies,
-            open(self.__cookies_path(), 'wb')
+            open(self.self._cookies_path, 'wb')
         )
 
     def _load_cookies(self) -> Optional[Dict[str, Dict[str, str]]]:
@@ -255,7 +256,7 @@ class Request:
             url=url,
             default_headers=self.default_headers,
             extra_headers=extra_headers,
-            cookies=self.cookies,
+            all_cookies=self.cookies,
             use_cookies=use_cookies
         )
 
@@ -272,7 +273,7 @@ class Request:
         )
 
         if use_cookies and self.keep_cookies and res and res.cookies:
-            self._set_cookies_for_url(url, res.cookies.get_dict(), save=self.cookies_path != None)
+            self._set_cookies_for_url(url, res.cookies.get_dict(), save=self._cookies_path != None)
 
         return res
 
